Crate rs_i18n

Crate rs_i18n 

Structs

Loader
I18n Loader It will load the configuration and i18n json files you can know target and sys language in this struct
UseI18n
I18n core

Enums

I18ns
i18n name enum