Loader

Struct Loader 

pub struct Loader { /* private fields */ }
I18n Loader It will load the configuration and i18n json files you can know target and sys language in this struct

Implementations

Source

impl Loader

pub fn new(path: Option<&str>) -> Self

Build a new Loader with configurations

params
  1. path - Option<&str> : path to load i18n json files (absolute path see following)
absoulte path

if use absolute path, you should pay attention that the path should write from root

means :

It is an absolute path based on the root directory as the standard

-- your project
|---- src
|       |-- main.rs (write Loader::new(Some("./i18n")))
|---- i18n
|       |-- en_US.json
|       |-- zh_CN.json
pub fn load(source: &Path) -> Self

Build a new Loader with specified target source path

pub fn get_sys_lang() -> I18ns

get system language from current system

pub fn get_configuration() -> PathBuf

get configuration and return source dir path

pub fn set_target(&self, target: I18ns)

pub fn target(&self) -> Arc<Mutex<I18ns>>

pub fn sources(&self) -> &Vec<PathBuf>

pub fn sys_lang(&self) -> &I18ns